<?php
/*
 * Add content box to footer
 */
add_action( 'wp_footer', 'pm_biwe_foot_content' );
function pm_biwe_foot_content() {
	$pm_biwe_options = get_option( 'pm_biwe_options' );
	$screen = $pm_biwe_options['screen'];
	$post_id = get_the_ID();

	$key = pm_biwe_front_show('html');

	// Check if welcome screen should show
	if( is_numeric( $key ) ) {
		wp_enqueue_style( 'pm-biwe-iconic', PM_BIWE_DIR.'css/font/css/open-iconic.min.css', '', PM_BIWE_VERSION, 'all' );
		$bgc = ( isset( $screen[$key]['bgc'] ) ) ? esc_attr( $screen[$key]['bgc'] ) : '' ;
		$txtc = ( isset( $screen[$key]['txtc'] ) ) ? esc_attr( $screen[$key]['txtc'] ) : '' ;
		$btnc = ( isset( $screen[$key]['btnc'] ) ) ? esc_attr( $screen[$key]['btnc'] ) : '' ;
		$content = ( isset( $screen[$key]['content'] ) ) ? stripslashes( $screen[$key]['content'] ) : '' ;
		$ar_code = ( empty( $screen[$key]['ar_code'] ) ) ? 'no' : 'show' ;
		$ar_url = ( isset( $screen[$key]['ar_url'] ) ) ? esc_url_raw( $screen[$key]['ar_url'] ) : '' ;
		$ar_name = ( isset( $screen[$key]['ar_name'] ) ) ? esc_attr( $screen[$key]['ar_name'] ) : '' ;
		$ar_email = ( isset( $screen[$key]['ar_email'] ) ) ? esc_attr( $screen[$key]['ar_email'] ) : '' ;
		$ar_name_label = ( isset( $screen[$key]['ar_name_label'] ) ) ? esc_attr( $screen[$key]['ar_name_label'] ) : '' ;
		$ar_email_label = ( isset( $screen[$key]['ar_email_label'] ) ) ? esc_attr( $screen[$key]['ar_email_label'] ) : '' ;
		$ar_button_label = ( isset( $screen[$key]['ar_button_label'] ) ) ? esc_attr( $screen[$key]['ar_button_label'] ) : '' ;
		$ar_hidden = ( isset( $screen[$key]['ar_hidden'] ) ) ? stripslashes( $screen[$key]['ar_hidden'] ) : '' ;
		?>
		<div id="pm-biwe-container" class="pm-biwe outer container" style="background-color:<?php echo $bgc; ?>;color:<?php echo $txtc; ?>; ">
			<!-- <div id="pm-biwe-close" class="pm-biwe close"><span class="oi" data-glyph="x"></span></div>-->
			<div id="pm-biwe-content-holder" class="pm-biwe inside content">
				<div id="pm-biwe-content" class="pm-biwe content holder">
					<?php
					echo $content;

					// Show opt-in or not
					if( $ar_code === 'show' ) { ?>
						<form method="POST" action="<?php echo $ar_url; ?>">
						<?php if( !empty( $ar_name ) ) { ?>
							<input type="text" placeholder="<?php echo $ar_name_label; ?>" name="<?php echo $ar_name; ?>">
							<?php } ?>
							<input type="text" placeholder="<?php echo $ar_email_label; ?>" name="<?php echo $ar_email; ?>">
							<?php echo $ar_hidden; ?>
							<input type="submit" name="submit" value="<?php echo $ar_button_label; ?>" style="background-color:<?php echo $btnc;?>;border:0;">
						</form>
					<?php } ?>
				</div>
			</div>
			<div id="pm-biwe-next-close"><span class="oi" data-glyph="chevron-bottom" style="color:<?php echo $bgc; ?>"></span></div>
		</div>
	<?php	}
}

/*
 * Enqueue front end scripts
 */
add_action( 'wp_enqueue_scripts', 'pm_biwe_enqueue_scripts' );
function pm_biwe_enqueue_scripts() {
	pm_biwe_front_show('scripts');
}

// Determine if we should display or not
function pm_biwe_front_show( $type ) {
	$pm_biwe_options = get_option( 'pm_biwe_options' );
	$screen = $pm_biwe_options['screen'];
	$post_id = get_the_ID();

	// For front page only
	if( is_front_page() ) {
		// Get the screen to show
		$key = ( isset( $pm_biwe_options['homescreen'] ) ) ? $pm_biwe_options['homescreen'] - 1 : 'no' ;
		$cookieset = ( isset( $_COOKIE['pm_biwe_hide_'.$key] ) ) ? esc_attr( $_COOKIE['pm_biwe_hide_'.$key] ) : '' ;
		
		// Check for cookies
		if( !$cookieset ) {
			$anim = ( isset( $screen[$key]['anim'] ) ) ? esc_attr( $screen[$key]['anim'] ) : '' ;
			$cookie = ( isset( $screen[$key]['cookie'] ) ) ? esc_attr( $screen[$key]['cookie'] ) : '' ;
			if( $type == 'scripts') {
				pm_biwe_enqueue_it( $anim, $cookie, $key );
			} elseif ( $type == 'html') {
				return $key;
			}
		} 
	} elseif ( $post_id ) { // Get POST ID for Posts and Pages
		$key = get_post_meta( $post_id, '_pm_biwe_mbox_data', true);
		$cookieset = ( isset( $_COOKIE['pm_biwe_hide_'.$key] ) ) ? esc_attr( $_COOKIE['pm_biwe_hide_'.$key] ) : '' ;
		$anim = ( isset( $screen[$key]['anim'] ) ) ? esc_attr( $screen[$key]['anim'] ) : '' ;
		$cookie = ( isset( $screen[$key]['cookie'] ) ) ? esc_attr( $screen[$key]['cookie'] ) : '' ;

		if( !$cookieset && $cookieset != $cookie ) {
			//echo 'anim: '.$anim.' cookie:'.$cookie.' key:'.$key;
			if( $type == 'scripts') {
				pm_biwe_enqueue_it( $anim, $cookie, $key );
			} elseif ( $type == 'html') {
				return $key;
			}
		}
		
	}
}
// Enqueue necessary front end scripts with custom values
function pm_biwe_enqueue_it( $anim, $cookie, $key ) {
	wp_enqueue_script( 'pm-biwe-front', PM_BIWE_DIR.'js/front.js' , array('jquery'), PM_BIWE_VERSION, true );
	wp_localize_script( 
		'pm-biwe-front',
		'pm_biwe_obj',
		array(
			'anim' => $anim,
			'cookie' => $cookie,
			'key' => $key
			)
		);
	wp_enqueue_style( 'pm-biwe-front', PM_BIWE_DIR.'css/front.css', '', PM_BIWE_VERSION, 'all' );
	wp_enqueue_style( 'pm-biwe-animate', PM_BIWE_DIR.'css/animate.css', 'pm-biwe-front', PM_BIWE_VERSION, 'all' );
}